// tofuproxy -- flexible HTTP/HTTPS proxy, TLS terminator, X.509 TOFU
//              manager, WARC/geminispace browser
// Copyright (C) 2021-2024 Sergey Matveev <stargrave@stargrave.org>
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, version 3 of the License.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package fifos

import (
	"bufio"
	"log"
	"os"
	"sync"
)

func del(l *sync.RWMutex, deleter func(string), p string) {
	for {
		fd, err := os.OpenFile(p, os.O_RDONLY, os.FileMode(0666))
		if err != nil {
			log.Fatalln(err)
		}
		var hosts []string
		scanner := bufio.NewScanner(fd)
		for scanner.Scan() {
			t := scanner.Text()
			if len(t) > 0 {
				hosts = append(hosts, t)
			}
		}
		fd.Close()
		l.Lock()
		for _, host := range hosts {
			log.Printf("%s: deleting host %s\n", p, host)
			deleter(host)
		}
		l.Unlock()
	}
}
