// tofuproxy -- flexible HTTP/HTTPS proxy, TLS terminator, X.509 TOFU
//              manager, WARC/geminispace browser
// Copyright (C) 2021-2024 Sergey Matveev <stargrave@stargrave.org>
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, version 3 of the License.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

package warc

import (
	"io"
	"os"
)

type UncompressedReader struct {
	*os.File
}

func NewUncompressedReader(warcPath string, offset int64) (*UncompressedReader, error) {
	fd, err := os.Open(warcPath)
	if err != nil {
		return nil, err
	}
	if _, err = fd.Seek(offset, io.SeekStart); err != nil {
		fd.Close()
		return nil, err
	}
	return &UncompressedReader{File: fd}, nil
}

func (r *UncompressedReader) Read(p []byte) (int, error) {
	return r.File.Read(p)
}

func (r *UncompressedReader) Close() error {
	return r.File.Close()
}

func (r *UncompressedReader) Offsets() []Offset {
	return nil
}
